@@ -1,69 +1,50 @@
-branch <- "cran/v0.4.0"  
+branch <- "cran/v0.5.0"  
 
 install_config <- list(
-  "1.8.0" = list(
+  "1.9.0" = list(
     "cpu" = list(
       "darwin" = list(
         "libtorch" = list(
-          url = "https://download.pytorch.org/libtorch/cpu/libtorch-macos-1.8.0.zip",
+          url = "https://download.pytorch.org/libtorch/cpu/libtorch-macos-1.9.0.zip",
           path = "libtorch/lib",
           filter = ".dylib",
-          md5hash = "23f07569e0c942260c8b13fa8c3289b8"
+          md5hash = "866298d95c8ae9529a3996f559911da4"
         ),
         "liblantern" = sprintf("https://storage.googleapis.com/torch-lantern-builds/refs/heads/%s/latest/macOS-cpu.zip", branch)
       ),
       "windows" = list(
         "libtorch" = list(
-          url = "https://download.pytorch.org/libtorch/cpu/libtorch-win-shared-with-deps-1.8.0%2Bcpu.zip",
+          url = "https://download.pytorch.org/libtorch/cpu/libtorch-win-shared-with-deps-1.9.0%2Bcpu.zip",
           path = "libtorch/lib",
           filter = ".dll",
-          md5hash = "f1ef43cbda67461f357a1463ac176a97"
+          md5hash = "96ff4f9c5d478342132bbf0d1ec4a34d"
         ),
         "liblantern" = sprintf("https://storage.googleapis.com/torch-lantern-builds/refs/heads/%s/latest/Windows-cpu.zip", branch)
       ),
       "linux" = list(
         "libtorch" = list(
-          url = "https://download.pytorch.org/libtorch/cpu/libtorch-cxx11-abi-shared-with-deps-1.8.0%2Bcpu.zip",
+          url = "https://download.pytorch.org/libtorch/cpu/libtorch-cxx11-abi-shared-with-deps-1.9.0%2Bcpu.zip",
           path = "libtorch/lib",
-          md5hash = "82969e58ae8cabee16746711850d6fd9"
+          md5hash = "5e0f412ffc7437b0631b86dcfa1a6368"
         ),
         "liblantern" = sprintf("https://storage.googleapis.com/torch-lantern-builds/refs/heads/%s/latest/Linux-cpu.zip", branch)
       )
     ),
-    "10.1" = list(
-      "linux" = list(
-        "libtorch" = list(
-          url = "https://download.pytorch.org/libtorch/cu101/libtorch-cxx11-abi-shared-with-deps-1.8.0%2Bcu101.zip",
-          path = "libtorch/lib",
-          md5hash = "ca8957f8cda1c82164192037b9411714"
-        ),
-        "liblantern" = sprintf("https://storage.googleapis.com/torch-lantern-builds/refs/heads/%s/latest/Linux-gpu-101.zip", branch)
-      ),
-      "windows" = list(
-        "libtorch" = list(
-          url = "https://download.pytorch.org/libtorch/cu101/libtorch-win-shared-with-deps-1.8.0%2Bcu101.zip",
-          path = "libtorch/lib",
-          filter = ".dll",
-          md5hash = "8351770ef9b2909d63353157c5d723c9"
-        ),
-        "liblantern" = sprintf("https://storage.googleapis.com/torch-lantern-builds/refs/heads/%s/latest/Windows-gpu-101.zip", branch)
-      )
-    ),
     "10.2" = list(
       "linux" = list(
         "libtorch" = list(
-          url = "https://download.pytorch.org/libtorch/cu102/libtorch-cxx11-abi-shared-with-deps-1.8.0.zip",
+          url = "https://download.pytorch.org/libtorch/cu102/libtorch-cxx11-abi-shared-with-deps-1.9.0%2Bcu102.zip",
           path = "libtorch/lib",
-          md5hash = "041594059e03381d8ef4d9f63c8e2c47"
+          md5hash = "439e074e788c7838459baeda8dbed5b0"
         ),
         "liblantern" = sprintf("https://storage.googleapis.com/torch-lantern-builds/refs/heads/%s/latest/Linux-gpu-102.zip", branch)
       ),
       "windows" = list(
         "libtorch" = list(
-          url = "https://download.pytorch.org/libtorch/cu102/libtorch-win-shared-with-deps-1.8.0.zip",
+          url = "https://download.pytorch.org/libtorch/cu102/libtorch-win-shared-with-deps-1.9.0%2Bcu102.zip",
           path = "libtorch/lib",
           filter = ".dll",
-          md5hash = "ca7a226590488cff5d6910191f8bfe91"
+          md5hash = "4419cb0b0c12517d29937023ccb00001"
         ),
         "liblantern" = sprintf("https://storage.googleapis.com/torch-lantern-builds/refs/heads/%s/latest/Windows-gpu-102.zip", branch)
       )
@@ -71,18 +52,18 @@ install_config <- list(
     "11.1" = list(
       "linux" = list(
         "libtorch" = list(
-          url = "https://download.pytorch.org/libtorch/cu111/libtorch-cxx11-abi-shared-with-deps-1.8.1%2Bcu111.zip",
+          url = "https://download.pytorch.org/libtorch/cu111/libtorch-cxx11-abi-shared-with-deps-1.9.0%2Bcu111.zip",
           path = "libtorch/lib",
-          md5hash = "fa3d3c05f9fef22e7b67bcf16cc6729e"
+          md5hash = "c5f69cfd23b3c564927a4e6fa697a553"
         ),
         "liblantern" = sprintf("https://storage.googleapis.com/torch-lantern-builds/refs/heads/%s/latest/Linux-gpu-111.zip", branch)
       ),
       "windows" = list(
         "libtorch" = list(
-          url = "https://download.pytorch.org/libtorch/cu111/libtorch-win-shared-with-deps-1.8.1%2Bcu111.zip",
+          url = "https://download.pytorch.org/libtorch/cu111/libtorch-win-shared-with-deps-1.9.0%2Bcu111.zip",
           path = "libtorch/lib",
           filter = ".dll",
-          md5hash = "8e0568dd97d09c2fef7e98ea458d2056"
+          md5hash = "fab3fdda5ec4f593cae39bd16c7161e3"
         ),
         "liblantern" = sprintf("https://storage.googleapis.com/torch-lantern-builds/refs/heads/%s/latest/Windows-gpu-111.zip", branch)
       )
@@ -91,7 +72,7 @@ install_config <- list(
 )
 
 
-install_path <- function(version = "1.8.0") {
+install_path <- function(version = "1.9.0") {
   path <- Sys.getenv("TORCH_HOME")
   if (nzchar(path))
     normalizePath(path, mustWork = FALSE)
@@ -226,6 +207,16 @@ install_type_windows <- function(version) {
   cuda_version
 }
 
+nvcc_version_from_path <- function(nvcc) {
+  suppressWarnings(
+    nvcc <- tryCatch(system2(nvcc, "--version", stdout = TRUE, stderr = TRUE), error = function(e) NULL)  
+  )
+  
+  if (is.null(nvcc) || !any(grepl("release", nvcc))) return(NULL)
+  
+  gsub(".*release |, V.*", "", nvcc[grepl("release", nvcc)])
+}
+
 #' @keywords internal
 install_type <- function(version) {
   if (nzchar(Sys.getenv("CUDA"))) return(Sys.getenv("CUDA"))
@@ -238,6 +229,7 @@ install_type <- function(version) {
   cuda_version <- NULL
   cuda_home <- Sys.getenv("CUDA_HOME")
   
+  # This file no longer exists with cuda >= 11
   if (nzchar(cuda_home)) {
     versions_file <- file.path(cuda_home, "version.txt")
     if (file.exists(versions_file)) {
@@ -245,6 +237,13 @@ install_type <- function(version) {
     }
   }
   
+  # Query nvcc from cuda in cuda_home path.
+  if (nzchar(cuda_home) && is.null(cuda_version)) {
+    nvcc_path <- file.path(cuda_home, "bin", "nvcc")
+    cuda_version <- nvcc_version_from_path(nvcc_path)
+  }
+  
+  # Try to find in conventional location.
   if (is.null(cuda_version)) {
     versions_file <- "/usr/local/cuda/version.txt"
     if (file.exists(versions_file)) {
@@ -252,11 +251,13 @@ install_type <- function(version) {
     }
   }
   
+  # Query nvcc from conventional location
   if (is.null(cuda_version)) {
-    nvcc <- tryCatch(system2("nvcc", "--version", stdout = TRUE, stderr = TRUE), error = function(e) NULL)
-    if (!is.null(nvcc)) {
-      cuda_version <- gsub(".*release |, V.*", "", nvcc[grepl("release", nvcc)])
-    }
+    cuda_version <- nvcc_version_from_path("/usr/local/cuda/bin/nvcc")
+  }
+  
+  if (is.null(cuda_version)) {
+    cuda_version <- nvcc_version_from_path("nvcc")
   }
   
   if (is.null(cuda_version)) return("cpu")
@@ -293,7 +294,7 @@ install_type <- function(version) {
 #' reported length, an increase of the \code{timeout} value should help.
 #' 
 #' @export
-install_torch <- function(version = "1.8.0", type = install_type(version = version), reinstall = FALSE,
+install_torch <- function(version = "1.9.0", type = install_type(version = version), reinstall = FALSE,
                           path = install_path(), timeout = 360, ...) {
   
   if (reinstall) {
@@ -351,7 +352,7 @@ install_torch <- function(version = "1.8.0", type = install_type(version = versi
 #' 
 #' 
 #' @export
-install_torch_from_file <- function(version = "1.8.0", type = install_type(version = version), libtorch, liblantern, ...) {
+install_torch_from_file <- function(version = "1.9.0", type = install_type(version = version), libtorch, liblantern, ...) {
   stopifnot(inherits(url(libtorch), "file"))
   stopifnot(inherits(url(liblantern), "file"))
 
@@ -370,7 +371,7 @@ install_torch_from_file <- function(version = "1.8.0", type = install_type(versi
 #' 
 #' 
 #' @export
-get_install_libs_url <- function(version = "1.8.0", type = install_type(version = version)) {
+get_install_libs_url <- function(version = "1.9.0", type = install_type(version = version)) {
 
   libtorch <- install_config[[version]][[type]][[install_os()]][["libtorch"]][["url"]]
   liblantern <- install_config[[version]][[type]][[install_os()]][["liblantern"]]
