@@ -643,12 +643,12 @@ nn_avg_pool3d <- nn_module(
 #'   Useful to pass to [nn_max_unpool2d()]. Default: `FALSE`
 #' 
 #' @examples
-#' # pool of square window of size=3, and target output size 13x12
-#' m = nn_fractional_max_pool2d(3, output_size=c(13, 12))
-#' # pool of square window and target output size being half of input image size
-#' m = nn_fractional_max_pool2d(3, output_ratio=c(0.5, 0.5))
-#' input = torch_randn(20, 16, 50, 32)
-#' output = m(input)
+# # pool of square window of size=3, and target output size 13x12
+# m = nn_fractional_max_pool2d(3, output_size=c(13, 12))
+# # pool of square window and target output size being half of input image size
+# m = nn_fractional_max_pool2d(3, output_ratio=c(0.5, 0.5))
+# input = torch_randn(20, 16, 50, 32)
+# output = m(input)
 #' 
 #' @export
 nn_fractional_max_pool2d <- nn_module(
@@ -680,8 +680,9 @@ nn_fractional_max_pool2d <- nn_module(
     if (!is.null(output_ratio) && !is.null(output_size))
       value_error("both output_size and oytput_ratio are not NULL")
     
-    if (!is.null(output_ratio) && (output_ratio > 1 || output_ratio < 0))
-      value_error("output_ratio must be between 0 and 1.")
+    if (!is.null(output_ratio))
+      if (any(output_ratio > 1 | output_ratio < 0))
+        value_error("output_ratio must be between 0 and 1.")
     
   },
   forward = function(input) {
@@ -748,8 +749,9 @@ nn_fractional_max_pool3d <- nn_module(
     if (!is.null(output_ratio) && !is.null(output_size))
       value_error("both output_size and oytput_ratio are not NULL")
     
-    if (!is.null(output_ratio) && (output_ratio > 1 || output_ratio < 0))
-      value_error("output_ratio must be between 0 and 1.")
+    if (!is.null(output_ratio))
+      if (any(output_ratio > 1 | output_ratio < 0))
+        value_error("output_ratio must be between 0 and 1.")
     
   },
   forward = function(input) {
