@@ -182,7 +182,7 @@ nnf_gumbel_softmax <- function(logits, tau = 1, hard = FALSE, dim = -1) {
     y_hard <- y_hard$scatter_(dim, index, 1)
     ret <- y_hard - y_soft$detach() + y_soft
   } else {
-    ret = y_soft
+    ret <- y_soft
   }
   ret
 }
@@ -514,6 +514,9 @@ nnf_threshold_ <- function(input, threshold, value) {
 #'   while the zero positions will be unchanged. If a BoolTensor is provided, positions with ``True``
 #'   is not allowed to attend while ``False`` values will be unchanged. If a FloatTensor
 #'   is provided, it will be added to the attention weight.
+#' @param avg_weights Logical; whether to average attn_output_weights over the
+#'   attention heads before outputting them. This doesn't change the returned 
+#'   value of attn_output; it only affects the returned attention weight matrix.
 #' @param in_proj_bias currently undocumented.
 #' @param bias_v currently undocumented.
 #' @param out_proj_bias currently undocumented.
@@ -540,6 +543,7 @@ nnf_multi_head_attention_forward <- function(
   key_padding_mask=NULL,           # type: Optional[Tensor]
   need_weights=TRUE,               # type: bool
   attn_mask=NULL,                  # type: Optional[Tensor]
+  avg_weights=TRUE,                # type: bool
   use_separate_proj_weight=FALSE,  # type: bool
   q_proj_weight=NULL,              # type: Optional[Tensor]
   k_proj_weight=NULL,              # type: Optional[Tensor]
@@ -581,7 +585,7 @@ nnf_multi_head_attention_forward <- function(
         v <- NULL
       } else {
         b_ <- in_proj_bias
-        start_ <- embed_dim
+        start_ <- embed_dim + 1
         end_ <- NULL
         w_ <- in_proj_weight[start_:N, ]
         if (!is.null(b_)) {
@@ -596,7 +600,7 @@ nnf_multi_head_attention_forward <- function(
       
       # This is inline in_proj function with in_proj_weight and in_proj_bias
       b_ <- in_proj_bias
-      start_ <- 0
+      start_ <- 1
       end_ <- embed_dim
       w_ <- in_proj_weight[start_:end_, ]
       if (!is.null(b_))
@@ -606,7 +610,7 @@ nnf_multi_head_attention_forward <- function(
       
       # This is inline in_proj function with in_proj_weight and in_proj_bias
       b_ <- in_proj_bias
-      start_ <- embed_dim
+      start_ <- embed_dim + 1
       end_ <- embed_dim * 2
       w_ <- in_proj_weight[start_:end_,]
       if (!is.null(b_))
@@ -615,7 +619,7 @@ nnf_multi_head_attention_forward <- function(
       
       # This is inline in_proj function with in_proj_weight and in_proj_bias
       b_ <- in_proj_bias
-      start_ <- embed_dim * 2
+      start_ <- embed_dim * 2 + 1
       end_ <- NULL
       w_ <- in_proj_weight[start_:N,]
       if (!is.null(b_)) {
@@ -730,7 +734,11 @@ nnf_multi_head_attention_forward <- function(
       tgt_len,
       src_len
     ))
-    return(list(attn_output, attn_output_weights$sum(dim = 2)/num_heads))
+    if (avg_weights) {
+      return(list(attn_output, attn_output_weights$sum(dim = 2)/num_heads))
+    } else {
+      return(list(attn_output, attn_output_weights))
+    }
   } else {
     return(list(attn_output, NULL))
   }
