@@ -5,26 +5,26 @@
 // https://github.com/pytorch/pytorch/blob/f531815526c69f432e46fadece44f5d3a9b70e30/torch/csrc/Generator.cpp
 
 // [[Rcpp::export]]
-Rcpp::XPtr<XPtrTorchGenerator> cpp_torch_generator () {
+XPtrTorchGenerator cpp_torch_generator () {
   XPtrTorchGenerator out = lantern_Generator();
-  return make_xptr<XPtrTorchGenerator>(out);
+  return XPtrTorchGenerator(out);
 }
 
 // [[Rcpp::export]]
-std::string cpp_generator_current_seed (Rcpp::XPtr<XPtrTorchGenerator> generator) {
-  uint64_t seed = lantern_Generator_current_seed(generator->get());
+std::string cpp_generator_current_seed (XPtrTorchGenerator generator) {
+  uint64_t seed = lantern_Generator_current_seed(generator.get());
   auto seed_str = std::to_string(seed);
   return seed_str;
 }
 
 // [[Rcpp::export]]
-void cpp_generator_set_current_seed (Rcpp::XPtr<XPtrTorchGenerator> generator, std::string seed) {
+void cpp_generator_set_current_seed (XPtrTorchGenerator generator, std::string seed) {
   
   uint64_t value;
   std::istringstream iss(seed);
   iss >> value;
   
-  lantern_Generator_set_current_seed(generator->get(), value);
+  lantern_Generator_set_current_seed(generator.get(), value);
 }
 
 // [[Rcpp::export]]
