@@ -74,6 +74,28 @@ XPtrTorchIndexTensorList to_index_tensor_list (XPtrTorchTensorList x)
   return out;
 }
 
+XPtrTorchOptionalIndexTensorList to_optional_index_tensor_list (XPtrTorchOptionalTensorList x)
+{
+  XPtrTorchOptionalIndexTensorList out = lantern_OptionalTensorList();
+  int64_t sze = lantern_OptionalTensorList_size(x.get());
+  
+  for (int i=0; i < sze; i++)
+  {
+    if (lantern_OptionalTensorList_at_is_null(x.get(), i))
+    {
+      lantern_OptionalTensorList_push_back(out.get(), nullptr, true);
+    }
+    else
+    {
+      XPtrTorchTensor t = lantern_OptionalTensorList_at(x.get(), i); 
+      XPtrTorchTensor zero_index = to_index_tensor (t);
+      lantern_OptionalTensorList_push_back(out.get(), zero_index.get(), false);
+    }
+  }
+  
+  return out;
+}
+
 // [[Rcpp::export]]
 bool cpp_torch_namespace__use_cudnn_rnn_flatten_weight ()
 {
